@@ -221,5 +221,9 @@ def run():
     app.run(host="localhost", port=port)
 
 
+def main():
+    print('run main')
+
+
 if __name__ == '__main__':
     run()
